"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const html_validate_1 = require("html-validate");
const directives = [
    "checked",
    "class",
    "disabled",
    "href",
    "maxlength",
    "minlength",
    "pattern",
    "readonly",
    "required",
    "selected",
    "src",
    "style",
    "value",
];
const matchNgAttr = new RegExp(`^ng-(?:attr-(.*)|(${directives.join("|")}))$`);
function* processAttribute(attr) {
    /* test if attribute contains interpolation */
    if (typeof attr.value === "string" && attr.value.match(/{{.*}}/)) {
        yield Object.assign({}, attr, {
            value: new html_validate_1.DynamicValue(attr.value),
        });
        return;
    }
    /* passthru original attribute */
    yield attr;
    /* setup ng-attr-x alias */
    const ngAttr = attr.key.match(matchNgAttr);
    if (ngAttr) {
        yield Object.assign({}, attr, {
            key: ngAttr[1] || ngAttr[2],
            value: new html_validate_1.DynamicValue(attr.value),
            originalAttribute: attr.key,
        });
    }
}
exports.processAttribute = processAttribute;
